<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Phone.Speech.Recognition

Windows Runtime (WinRT) APIs for for the `Windows.Phone.Speech.Recognition` namespace.

This package provides the `winrt.windows.phone.speech.recognition` module.
